<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\ActivityBundle\Export\Filter\ACPFilters;

use Chill\ActivityBundle\Entity\Activity;
use Chill\ActivityBundle\Entity\ActivityType;
use Chill\ActivityBundle\Repository\ActivityTypeRepositoryInterface;
use Chill\MainBundle\Export\FilterInterface;
use Chill\MainBundle\Templating\TranslatableStringHelperInterface;
use Chill\PersonBundle\Export\Declarations;
use Doctrine\ORM\QueryBuilder;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\FormBuilderInterface;

class ActivityTypeFilter implements FilterInterface
{
    public function __construct(private readonly ActivityTypeRepositoryInterface $activityTypeRepository, private readonly TranslatableStringHelperInterface $translatableStringHelper)
    {
    }

    public function addRole(): ?string
    {
        return null;
    }

    public function alterQuery(QueryBuilder $qb, $data)
    {
        $qb->andWhere(
            $qb->expr()->exists(
                'SELECT 1 FROM ' . Activity::class . ' act_type_filter_activity
                WHERE act_type_filter_activity.activityType IN (:act_type_filter_activity_types) AND act_type_filter_activity.accompanyingPeriod = acp'
            )
        );
        $qb->setParameter('act_type_filter_activity_types', $data['accepted_activitytypes']);
    }

    public function applyOn()
    {
        return Declarations::ACP_TYPE;
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        $builder->add('accepted_activitytypes', EntityType::class, [
            'class' => ActivityType::class,
            'choices' => $this->activityTypeRepository->findAllActive(),
            'choice_label' => fn (ActivityType $aty) => ($aty->hasCategory() ? $this->translatableStringHelper->localize($aty->getCategory()->getName()) . ' > ' : '')
            .
            $this->translatableStringHelper->localize($aty->getName()),
            'multiple' => true,
            'expanded' => true,
        ]);
    }

    public function describeAction($data, $format = 'string'): array
    {
        $types = [];

        foreach ($data['accepted_activitytypes'] as $aty) {
            $types[] = $this->translatableStringHelper->localize($aty->getName());
        }

        return ['Filtered by activity types: only %activitytypes%', [
            '%activitytypes%' => implode(', ', $types),
        ]];
    }

    public function getTitle(): string
    {
        return 'Filter accompanying course by activity type';
    }
}
