<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\ActivityBundle\Export\Filter;

use Chill\ActivityBundle\Entity\Activity;
use Chill\ActivityBundle\Export\Declarations;
use Chill\MainBundle\Entity\UserJob;
use Chill\MainBundle\Export\FilterInterface;
use Chill\MainBundle\Templating\TranslatableStringHelperInterface;
use Doctrine\ORM\QueryBuilder;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\FormBuilderInterface;

class UsersJobFilter implements FilterInterface
{
    public function __construct(private readonly TranslatableStringHelperInterface $translatableStringHelper)
    {
    }

    public function addRole(): ?string
    {
        return null;
    }

    public function alterQuery(QueryBuilder $qb, $data)
    {
        $qb
            ->andWhere(
                $qb->expr()->exists(
                    'SELECT 1 FROM ' . Activity::class . ' activity_users_job_filter_act
                JOIN activity_users_job_filter_act.users users WHERE users.userJob IN (:activity_users_job_filter_jobs) AND  activity_users_job_filter_act = activity '
                )
            )
            ->setParameter('activity_users_job_filter_jobs', $data['jobs']);
    }

    public function applyOn()
    {
        return Declarations::ACTIVITY;
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        $builder->add('jobs', EntityType::class, [
            'class' => UserJob::class,
            'choice_label' => fn (UserJob $j) => $this->translatableStringHelper->localize($j->getLabel()),
            'multiple' => true,
            'expanded' => true,
        ]);
    }

    public function describeAction($data, $format = 'string')
    {
        return ['export.filter.activity.by_usersjob.Filtered activity by users job: only %jobs%', [
            '%jobs%' => implode(
                ', ',
                array_map(
                    fn (UserJob $job) => $this->translatableStringHelper->localize($job->getLabel()),
                    $data['jobs']->toArray()
                )
            ),
        ]];
    }

    public function getTitle()
    {
        return 'export.filter.activity.by_usersjob.Filter by users job';
    }
}
