<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\ActivityBundle\Export\Filter;

use Chill\ActivityBundle\Entity\Activity;
use Chill\ActivityBundle\Export\Declarations;
use Chill\MainBundle\Entity\Scope;
use Chill\MainBundle\Export\FilterInterface;
use Chill\MainBundle\Repository\ScopeRepositoryInterface;
use Chill\MainBundle\Templating\TranslatableStringHelperInterface;
use Doctrine\ORM\QueryBuilder;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\FormBuilderInterface;

class UsersScopeFilter implements FilterInterface
{
    public function __construct(private readonly ScopeRepositoryInterface $scopeRepository, private readonly TranslatableStringHelperInterface $translatableStringHelper)
    {
    }

    public function addRole(): ?string
    {
        return null;
    }

    public function alterQuery(QueryBuilder $qb, $data)
    {
        $qb
            ->andWhere(
                $qb->expr()->exists(
                    'SELECT 1 FROM ' . Activity::class . ' activity_users_scope_filter_act
                JOIN activity_users_scope_filter_act.users users WHERE users.mainScope IN (:activity_users_scope_filter_scopes) AND  activity_users_scope_filter_act = activity '
                )
            )
            ->setParameter('activity_users_scope_filter_scopes', $data['scopes']);
    }

    public function applyOn()
    {
        return Declarations::ACTIVITY;
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        $builder->add('scopes', EntityType::class, [
            'class' => Scope::class,
            'choices' => $this->scopeRepository->findAllActive(),
            'choice_label' => fn (Scope $s) => $this->translatableStringHelper->localize($s->getName()),
            'multiple' => true,
            'expanded' => true,
        ]);
    }

    public function describeAction($data, $format = 'string')
    {
        return ['export.filter.activity.by_usersscope.Filtered activity by users scope: only %scopes%', [
            '%scopes%' => implode(
                ', ',
                array_map(
                    fn (Scope $s) => $this->translatableStringHelper->localize($s->getName()),
                    $data['scopes']->toArray()
                )
            ),
        ]];
    }

    public function getTitle()
    {
        return 'export.filter.activity.by_usersscope.Filter by users scope';
    }
}
