<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\ActivityBundle\Tests\Export\Aggregator\PersonAggregators;

use Chill\ActivityBundle\Export\Aggregator\PersonAggregators\ActivityReasonAggregator;
use Chill\MainBundle\Test\Export\AbstractAggregatorTest;
use Doctrine\ORM\EntityManagerInterface;
use Prophecy\PhpUnit\ProphecyTrait;

/**
 * @internal
 * @coversNothing
 */
final class ActivityReasonAggregatorTest extends AbstractAggregatorTest
{
    use ProphecyTrait;

    private ActivityReasonAggregator $aggregator;

    protected function setUp(): void
    {
        self::bootKernel();

        $this->aggregator = self::$container->get('chill.activity.export.reason_aggregator');

        $request = $this->prophesize()
            ->willExtend(\Symfony\Component\HttpFoundation\Request::class);

        $request->getLocale()->willReturn('fr');

        self::$container->get('request_stack')
            ->push($request->reveal());
    }

    public function getAggregator()
    {
        return $this->aggregator;
    }

    public function getFormData(): array
    {
        return [
            ['level' => 'reasons'],
            ['level' => 'categories'],
        ];
    }

    public function getQueryBuilders(): array
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        $em = self::$container->get(EntityManagerInterface::class);

        return [
            $em->createQueryBuilder()
                ->select('count(activity.id)')
                ->from('ChillActivityBundle:Activity', 'activity'),
            $em->createQueryBuilder()
                ->select('count(activity.id)')
                ->from('ChillActivityBundle:Activity', 'activity')
                ->join('activity.reasons', 'actreasons'),
            $em->createQueryBuilder()
                ->select('count(activity.id)')
                ->from('ChillActivityBundle:Activity', 'activity')
                ->join('activity.reasons', 'actreasons')
                ->join('actreasons.category', 'actreasoncat'),
        ];
    }
}
