<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\ActivityBundle\Tests\Export\Filter\ACPFilters;

use Chill\ActivityBundle\Entity\Activity;
use Chill\ActivityBundle\Entity\ActivityType;
use Chill\ActivityBundle\Export\Filter\ACPFilters\ActivityTypeFilter;
use Chill\MainBundle\Test\Export\AbstractFilterTest;
use Chill\PersonBundle\Entity\AccompanyingPeriod;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\Query\Expr;

/**
 * @internal
 * @coversNothing
 */
final class ActivityTypeFilterTest extends AbstractFilterTest
{
    private ActivityTypeFilter $filter;

    protected function setUp(): void
    {
        self::bootKernel();

        $this->filter = self::$container->get('chill.activity.export.filter_activitytype');
    }

    public function getFilter()
    {
        return $this->filter;
    }

    public function getFormData(): array
    {
        $em = self::$container->get(EntityManagerInterface::class);

        $array = $em->createQueryBuilder()
            ->from(ActivityType::class, 'at')
            ->select('at')
            ->getQuery()
            ->getResult();

        $data = [];

        foreach ($array as $a) {
            $data[] = [
                'accepted_activitytypes' => $a,
            ];
        }

        return $data;
    }

    public function getQueryBuilders(): array
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        $em = self::$container->get(EntityManagerInterface::class);

        return [
            $em->createQueryBuilder()
                ->select('count(activity.id)')
                ->from(AccompanyingPeriod::class, 'acp')
                ->join(Activity::class, 'activity', Expr\Join::WITH, 'activity.accompanyingPeriod = acp')
                ->join('activity.activityType', 'acttype'),
        ];
    }
}
