<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\ActivityBundle\Tests\Export\Filter;

use Chill\ActivityBundle\Export\Filter\PersonFilters\ActivityReasonFilter;
use Chill\MainBundle\Test\Export\AbstractFilterTest;
use Doctrine\Common\Collections\ArrayCollection;
use Prophecy\PhpUnit\ProphecyTrait;

/**
 * @internal
 * @coversNothing
 */
final class ActivityReasonFilterTest extends AbstractFilterTest
{
    use ProphecyTrait;

    private ActivityReasonFilter $filter;

    protected function setUp(): void
    {
        self::bootKernel();

        $this->filter = self::$container->get('chill.activity.export.reason_filter');

        $request = $this->prophesize()
            ->willExtend(\Symfony\Component\HttpFoundation\Request::class);

        $request->getLocale()->willReturn('fr');

        self::$container->get('request_stack')
            ->push($request->reveal());
    }

    public function getFilter()
    {
        return $this->filter;
    }

    public function getFormData()
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        $em = self::$kernel->getContainer()
            ->get('doctrine.orm.entity_manager');

        $reasons = $em->createQuery('SELECT reason '
                . 'FROM ChillActivityBundle:ActivityReason reason')
            ->getResult();

        // generate an array of 5 different combination of results
        for ($i = 0; 5 > $i; ++$i) {
            $r[] = ['reasons' => new ArrayCollection(array_splice($reasons, ($i + 1) * -1))];
        }

        return $r;
    }

    public function getQueryBuilders()
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        $em = self::$kernel->getContainer()
            ->get('doctrine.orm.entity_manager');

        return [
            $em->createQueryBuilder()
                ->select('count(activity.id)')
                ->from('ChillActivityBundle:Activity', 'activity'),
            $em->createQueryBuilder()
                ->select('count(activity.id)')
                ->from('ChillActivityBundle:Activity', 'activity')
                ->join('activity.reasons', 'reasons'),
            $em->createQueryBuilder()
                ->select('count(activity.id)')
                ->from('ChillActivityBundle:Activity', 'activity')
                ->join('activity.reasons', 'reasons')
                ->join('reasons.category', 'category'),
        ];
    }
}
