<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\ActivityBundle\Tests\Export\Filter;

use Chill\ActivityBundle\Export\Filter\PersonFilters\PersonHavingActivityBetweenDateFilter;
use Chill\MainBundle\Test\Export\AbstractFilterTest;
use DateTime;
use function array_slice;

/**
 * @internal
 * @coversNothing
 */
final class PersonHavingActivityBetweenDateFilterTest extends AbstractFilterTest
{
    private PersonHavingActivityBetweenDateFilter $filter;

    protected function setUp(): void
    {
        self::bootKernel();

        $this->filter = self::$container->get('chill.activity.export.person_having_an_activity_between_date_filter');

        $request = $this->prophesize()
            ->willExtend(\Symfony\Component\HttpFoundation\Request::class);

        $request->getLocale()->willReturn('fr');

        self::$container->get('request_stack')
            ->push($request->reveal());
    }

    public function getFilter()
    {
        return $this->filter;
    }

    public function getFormData()
    {
        $date_from = DateTime::createFromFormat('Y-m-d', '2015-01-15');
        $date_to = new DateTime(); // today
        $reasons = $this->getActivityReasons();

        $data = [];

        for ($i = 0; 4 > $i; ++$i) {
            $data[] = [
                'date_from' => $date_from,
                'date_to' => $date_to,
                'reasons' => array_slice($reasons, 0, 1 + $i),
            ];
        }

        return $data;
    }

    public function getQueryBuilders()
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        $em = self::$kernel->getContainer()
            ->get('doctrine.orm.entity_manager');

        return [
            $em->createQueryBuilder()
                ->select('count(person.id)')
                ->from('ChillPersonBundle:Person', 'person')
                // add a fake where clause
                ->where('person.id > 0'),
            $em->createQueryBuilder()
                ->select('count(person.id)')
                ->from('ChillActivityBundle:Activity', 'activity')
                ->join('activity.person', 'person')
                // add a fake where clause
                ->where('person.id > 0'),
        ];
    }

    /**
     * Return all activity reasons.
     *
     * @return \Chill\ActivityBundle\Entity\ActivityReason[]
     */
    private function getActivityReasons()
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        return self::$kernel->getContainer()
            ->get('chill_activity.repository.reason')
            ->findAll();
    }
}
