<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\AsideActivityBundle\Export\Aggregator;

use Chill\AsideActivityBundle\Export\Declarations;
use Chill\MainBundle\Export\AggregatorInterface;
use Chill\MainBundle\Repository\ScopeRepositoryInterface;
use Chill\MainBundle\Templating\TranslatableStringHelperInterface;
use Doctrine\ORM\QueryBuilder;
use Symfony\Component\Form\FormBuilderInterface;

use function in_array;

class ByUserScopeAggregator implements AggregatorInterface
{
    public function __construct(private readonly ScopeRepositoryInterface $scopeRepository, private readonly TranslatableStringHelperInterface $translatableStringHelper)
    {
    }

    public function addRole(): ?string
    {
        return null;
    }

    public function alterQuery(QueryBuilder $qb, $data)
    {
        if (!in_array('aside_user', $qb->getAllAliases(), true)) {
            $qb->leftJoin('aside.agent', 'aside_user');
        }

        $qb
            ->addSelect('IDENTITY(aside_user.mainScope) AS aside_activity_user_scope_aggregator')
            ->addGroupBy('aside_activity_user_scope_aggregator');
    }

    public function applyOn()
    {
        return Declarations::ASIDE_ACTIVITY_TYPE;
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        // nothing to add in the form
    }

    public function getLabels($key, array $values, $data)
    {
        return function ($value): string {
            if ('_header' === $value) {
                return 'Users \'s scope';
            }

            if (null === $value || '' === $value) {
                return '';
            }

            $s = $this->scopeRepository->find($value);

            return $this->translatableStringHelper->localize(
                $s->getName()
            );
        };
    }

    public function getQueryKeys($data): array
    {
        return ['aside_activity_user_scope_aggregator'];
    }

    public function getTitle()
    {
        return 'export.aggregator.Aggregate by user scope';
    }
}
