<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\AsideActivityBundle\Export\Filter;

use Chill\AsideActivityBundle\Entity\AsideActivity;
use Chill\AsideActivityBundle\Export\Declarations;
use Chill\MainBundle\Entity\UserJob;
use Chill\MainBundle\Export\FilterInterface;
use Chill\MainBundle\Templating\TranslatableStringHelperInterface;
use Doctrine\ORM\QueryBuilder;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\FormBuilderInterface;

class ByUserJobFilter implements FilterInterface
{
    public function __construct(private readonly TranslatableStringHelperInterface $translatableStringHelper)
    {
    }

    public function addRole(): ?string
    {
        return null;
    }

    public function alterQuery(QueryBuilder $qb, $data)
    {
        $qb
            ->andWhere(
                $qb->expr()->exists(
                    'SELECT 1 FROM ' . AsideActivity::class . ' aside_activity_user_job_filter_act
                JOIN aside_activity_user_job_filter_act.agent aside_activity_user_job_filter_user WHERE aside_activity_user_job_filter_user.userJob IN (:aside_activity_user_job_filter_jobs) AND aside_activity_user_job_filter_act = aside'
                )
            )
            ->setParameter('aside_activity_user_job_filter_jobs', $data['jobs']);
    }

    public function applyOn()
    {
        return Declarations::ASIDE_ACTIVITY_TYPE;
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        $builder->add('jobs', EntityType::class, [
            'class' => UserJob::class,
            'choice_label' => fn (UserJob $j) => $this->translatableStringHelper->localize($j->getLabel()),
            'multiple' => true,
            'expanded' => true,
        ]);
    }

    public function describeAction($data, $format = 'string')
    {
        return ['export.filter.Filtered aside activities by user jobs: only %jobs%', [
            '%jobs%' => implode(
                ', ',
                array_map(
                    fn (UserJob $job) => $this->translatableStringHelper->localize($job->getLabel()),
                    $data['jobs']->toArray()
                )
            ),
        ]];
    }

    public function getTitle()
    {
        return 'export.filter.Filter by user jobs';
    }
}
