<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\AsideActivityBundle\Export\Filter;

use Chill\AsideActivityBundle\Entity\AsideActivity;
use Chill\AsideActivityBundle\Export\Declarations;
use Chill\MainBundle\Entity\Scope;
use Chill\MainBundle\Export\FilterInterface;
use Chill\MainBundle\Repository\ScopeRepositoryInterface;
use Chill\MainBundle\Templating\TranslatableStringHelperInterface;
use Doctrine\ORM\QueryBuilder;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\FormBuilderInterface;

class ByUserScopeFilter implements FilterInterface
{
    public function __construct(private readonly ScopeRepositoryInterface $scopeRepository, private readonly TranslatableStringHelperInterface $translatableStringHelper)
    {
    }

    public function addRole(): ?string
    {
        return null;
    }

    public function alterQuery(QueryBuilder $qb, $data)
    {
        $qb
            ->andWhere(
                $qb->expr()->exists(
                    'SELECT 1 FROM ' . AsideActivity::class . ' aside_activity_user_scope_filter_act
                JOIN aside_activity_user_scope_filter_act.agent aside_activity_user_scope_filter_user WHERE aside_activity_user_scope_filter_user.mainScope IN (:aside_activity_user_scope_filter_scopes) AND  aside_activity_user_scope_filter_act = aside '
                )
            )
            ->setParameter('aside_activity_user_scope_filter_scopes', $data['scopes']);
    }

    public function applyOn()
    {
        return Declarations::ASIDE_ACTIVITY_TYPE;
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        $builder->add('scopes', EntityType::class, [
            'class' => Scope::class,
            'choices' => $this->scopeRepository->findAllActive(),
            'choice_label' => fn (Scope $s) => $this->translatableStringHelper->localize($s->getName()),
            'multiple' => true,
            'expanded' => true,
        ]);
    }

    public function describeAction($data, $format = 'string')
    {
        return ['export.filter.Filtered aside activities by user scope: only %scopes%', [
            '%scopes%' => implode(
                ', ',
                array_map(
                    fn (Scope $s) => $this->translatableStringHelper->localize($s->getName()),
                    $data['scopes']->toArray()
                )
            ),
        ]];
    }

    public function getTitle()
    {
        return 'export.filter.Filter by user scope';
    }
}
