<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\DocStoreBundle\Controller;

use Chill\DocStoreBundle\ChillDocStoreBundle;
use Chill\DocStoreBundle\Entity\DocumentCategory;
use Chill\DocStoreBundle\Entity\PersonDocument;
use Chill\DocStoreBundle\Form\DocumentCategoryType;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

/**
 * @Route("/{_locale}/admin/document/category")
 */
class DocumentCategoryController extends AbstractController
{
    /**
     * @Route("/{bundleId}/{idInsideBundle}", name="document_category_delete", methods="DELETE")
     */
    public function delete(Request $request, mixed $bundleId, mixed $idInsideBundle): Response
    {
        $em = $this->getDoctrine()->getManager();
        $documentCategory = $em
            ->getRepository(\Chill\DocStoreBundle\Entity\DocumentCategory::class)
            ->findOneBy(
                ['bundleId' => $bundleId, 'idInsideBundle' => $idInsideBundle]
            );

        if ($this->isCsrfTokenValid('delete' . $bundleId . $idInsideBundle, $request->request->get('_token'))) {
            $em->remove($documentCategory);
            $em->flush();
        }

        return $this->redirectToRoute('document_category_index');
    }

    /**
     * @Route("/{bundleId}/{idInsideBundle}/edit", name="document_category_edit", methods="GET|POST")
     */
    public function edit(Request $request, mixed $bundleId, mixed $idInsideBundle): Response
    {
        $em = $this->getDoctrine()->getManager();
        $documentCategory = $em
            ->getRepository(\Chill\DocStoreBundle\Entity\DocumentCategory::class)
            ->findOneBy(
                ['bundleId' => $bundleId, 'idInsideBundle' => $idInsideBundle]
            );

        $form = $this->createForm(DocumentCategoryType::class, $documentCategory);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $this->getDoctrine()->getManager()->flush();

            return $this->redirectToRoute('document_category_index', [
                'bundleId' => $documentCategory->getBundleId(),
                'idInsideBundle' => $documentCategory->getIdInsideBundle(), ]);
        }

        return $this->render('ChillDocStoreBundle:DocumentCategory:edit.html.twig', [
            'document_category' => $documentCategory,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/", name="document_category_index", methods="GET")
     */
    public function index(): Response
    {
        $em = $this->getDoctrine()->getManager();
        $categories = $em->getRepository(DocumentCategory::class)->findAll();

        return $this->render(
            'ChillDocStoreBundle:DocumentCategory:index.html.twig',
            [
                'document_categories' => $categories,
            ]
        );
    }

    /**
     * @Route("/new", name="document_category_new", methods="GET|POST")
     */
    public function new(Request $request): Response
    {
        $em = $this->getDoctrine()->getManager();

        $nextId = $em
            ->createQuery(
                'SELECT MAX(c.idInsideBundle) + 1 FROM ChillDocStoreBundle:DocumentCategory c'
            )
            ->getSingleResult();

        $documentCategory = new DocumentCategory(
            ChillDocStoreBundle::class,
            reset($nextId)
        );

        $documentCategory
            ->setDocumentClass(PersonDocument::class);

        $form = $this->createForm(DocumentCategoryType::class, $documentCategory);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $em = $this->getDoctrine()->getManager();
            $em->persist($documentCategory);
            $em->flush();

            return $this->redirectToRoute('document_category_index');
        }

        return $this->render('ChillDocStoreBundle:DocumentCategory:new.html.twig', [
            'document_category' => $documentCategory,
            'form' => $form->createView(),
        ]);
    }

    /**
     * @Route("/{bundleId}/{idInsideBundle}", name="document_category_show", methods="GET")
     */
    public function show(mixed $bundleId, mixed $idInsideBundle): Response
    {
        $em = $this->getDoctrine()->getManager();
        $documentCategory = $em
            ->getRepository(\Chill\DocStoreBundle\Entity\DocumentCategory::class)
            ->findOneBy(
                ['bundleId' => $bundleId, 'idInsideBundle' => $idInsideBundle]
            );

        return $this->render(
            'ChillDocStoreBundle:DocumentCategory:show.html.twig',
            ['document_category' => $documentCategory]
        );
    }
}
