<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\DocStoreBundle\Service;

use Chill\DocStoreBundle\Entity\StoredObject;
use DateTimeInterface;

interface StoredObjectManagerInterface
{
    public function getLastModified(StoredObject $document): DateTimeInterface;

    /**
     * Get the content of a StoredObject.
     *
     * @param StoredObject $document The document.
     *
     * @return string The retrieved content in clear.
     */
    public function read(StoredObject $document): string;

    /**
     * Set the content of a StoredObject.
     *
     * @param StoredObject $document The document.
     * @param $clearContent The content to store in clear.
     */
    public function write(StoredObject $document, string $clearContent): void;
}
