<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\MainBundle\Export\Helper;

use Chill\MainBundle\Repository\UserRepositoryInterface;
use Chill\MainBundle\Templating\Entity\UserRender;
use function count;
use const SORT_NUMERIC;

class UserHelper
{
    public function __construct(private readonly UserRender $userRender, private readonly UserRepositoryInterface $userRepository)
    {
    }

    public function getLabel($key, array $values, string $header): callable
    {
        return function ($value) use ($header) {
            if ('_header' === $value) {
                return $header;
            }

            if (null === $value || null === $user = $this->userRepository->find($value)) {
                return '';
            }

            return $this->userRender->renderString($user, []);
        };
    }

    public function getLabelMulti($key, array $values, string $header): callable
    {
        return function ($value) use ($header) {
            if ('_header' === $value) {
                return $header;
            }

            if (null === $value) {
                return '';
            }

            $decoded = json_decode($value, null, 512, JSON_THROW_ON_ERROR);

            if (0 === count($decoded)) {
                return '';
            }

            return
                implode(
                    '|',
                    array_map(
                        function (int $userId) {
                            $user = $this->userRepository->find($userId);

                            if (null === $user) {
                                return '';
                            }

                            return $this->userRender->renderString($user, []);
                        },
                        array_unique(
                            array_filter($decoded, static fn (?int $userId) => null !== $userId),
                            SORT_NUMERIC
                        )
                    )
                );
        };
    }
}
