<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\MainBundle\Form\DataMapper;

use Chill\MainBundle\Entity\Center;
use Chill\MainBundle\Entity\Regroupment;
use Chill\MainBundle\Repository\RegroupmentRepository;
use Exception;
use Symfony\Component\Form\DataMapperInterface;
use Symfony\Component\Form\FormInterface;
use function array_key_exists;
use function count;

class ExportPickCenterDataMapper implements DataMapperInterface
{
    protected RegroupmentRepository $regroupmentRepository;

    public function mapDataToForms($data, $forms): void
    {
        if (null === $data) {
            return;
        }

        /** @var array<string, FormInterface> $form */
        $form = iterator_to_array($forms);

        $pickedRegroupment = [];

        foreach ($this->regroupmentRepository->findAll() as $regroupment) {
            /** @phpstan-ignore-next-line  */
            [$contained, $notContained] = $regroupment->getCenters()->partition(static fn (Center $center): bool => false);

            if (0 === count($notContained)) {
                $pickedRegroupment[] = $regroupment;
            }
        }

        $form['regroupment']->setData($pickedRegroupment);
        $form['centers']->setData($data);
    }

    public function mapFormsToData($forms, &$data): void
    {
        /** @var array<string, FormInterface> $forms */
        $forms = iterator_to_array($forms);

        $centers = [];

        foreach ($forms['center']->getData() as $center) {
            $centers[spl_object_hash($center)] = $center;
        }

        if (array_key_exists('regroupment', $forms)) {
            /** @var Regroupment $regroupment */
            foreach ($forms['regroupment']->getData() as $regroupment) {
                foreach ($regroupment->getCenters() as $center) {
                    $centers[spl_object_hash($center)] = $center;
                }
            }
        }

        $data = array_values($centers);
    }
}
