<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\MainBundle\Form\Type\Export;

use Chill\MainBundle\Entity\Center;
use Chill\MainBundle\Entity\Regroupment;
use Chill\MainBundle\Export\ExportManager;
use Chill\MainBundle\Form\DataMapper\ExportPickCenterDataMapper;
use Chill\MainBundle\Repository\RegroupmentRepository;
use Chill\MainBundle\Security\Authorization\AuthorizationHelperInterface;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;

use Symfony\Component\Security\Core\User\UserInterface;
use function count;

/**
 * Pick centers amongst available centers for the user.
 */
final class PickCenterType extends AbstractType
{
    public const CENTERS_IDENTIFIERS = 'c';

    private readonly UserInterface $user;

    public function __construct(
        TokenStorageInterface $tokenStorage,
        private readonly ExportManager $exportManager,
        private readonly RegroupmentRepository $regroupmentRepository,
        private readonly AuthorizationHelperInterface $authorizationHelper
    ) {
        $this->user = $tokenStorage->getToken()->getUser();
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $export = $this->exportManager->getExport($options['export_alias']);
        $centers = $this->authorizationHelper->getReachableCenters(
            $this->user,
            $export->requiredRole()
        );

        $builder->add('center', EntityType::class, [
            'class' => Center::class,
            'label' => 'center',
            'choices' => $centers,
            'multiple' => true,
            'expanded' => true,
            'choice_label' => static fn (Center $c) => $c->getName(),
            'data' => $centers,
        ]);

        if (count($this->regroupmentRepository->findAllActive()) > 0) {
            $builder->add('regroupment', EntityType::class, [
                'class' => Regroupment::class,
                'label' => 'regroupment',
                'multiple' => true,
                'expanded' => true,
                'choices' => $this->regroupmentRepository->findAllActive(),
                'choice_label' => static fn (Regroupment $r) => $r->getName(),
            ]);
        }

        $builder->setDataMapper(new ExportPickCenterDataMapper());
    }

    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setRequired('export_alias');
    }
}
