<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\MainBundle\Repository;

use Chill\MainBundle\Entity\User;
use Doctrine\Persistence\ObjectRepository;

interface UserRepositoryInterface extends ObjectRepository
{
    public function countBy(array $criteria): int;

    public function countByActive(): int;

    public function countByNotHavingAttribute(string $key): int;

    public function countByUsernameOrEmail(string $pattern): int;

    public function find($id, $lockMode = null, $lockVersion = null): ?User;

    /**
     * @return User[]
     */
    public function findAll(): array;

    /**
     * @param mixed|null $limit
     * @param mixed|null $offset
     *
     * @return User[]
     */
    public function findBy(array $criteria, ?array $orderBy = null, $limit = null, $offset = null): array;

    /**
     * @return array|User[]
     */
    public function findByActive(?array $orderBy = null, ?int $limit = null, ?int $offset = null): array;

    /**
     * Find users which does not have a key on attribute column.
     *
     * @return array|User[]
     */
    public function findByNotHavingAttribute(string $key, ?int $limit = null, ?int $offset = null): array;

    public function findByUsernameOrEmail(string $pattern, ?array $orderBy = [], ?int $limit = null, ?int $offset = null): array;

    public function findOneBy(array $criteria, ?array $orderBy = null): ?User;

    public function findOneByUsernameOrEmail(string $pattern): ?User;

    /**
     * Get the users having a specific flags.
     *
     * If provided, only the users amongst "filtered users" are searched. This
     * allows to make a first search amongst users based on role and center
     * and, then filter those users having some flags.
     *
     * @param \Chill\MainBundle\Entity\User[] $amongstUsers
     * @param mixed $flag
     */
    public function findUsersHavingFlags($flag, array $amongstUsers = []): array;

    public function getClassName(): string;
}
