<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\MainBundle\Templating\Listing;

use DateTimeImmutable;
use Symfony\Component\Form\FormFactoryInterface;
use Symfony\Component\HttpFoundation\RequestStack;

class FilterOrderHelperBuilder
{
    private array $checkboxes = [];

    private array $dateRanges = [];

    private ?array $searchBoxFields = null;

    public function __construct(private readonly FormFactoryInterface $formFactory, private readonly RequestStack $requestStack)
    {
    }

    public function addCheckbox(string $name, array $choices, ?array $default = [], ?array $trans = []): self
    {
        $this->checkboxes[$name] = ['choices' => $choices, 'default' => $default, 'trans' => $trans];

        return $this;
    }

    public function addDateRange(string $name, ?string $label = null, ?DateTimeImmutable $from = null, ?DateTimeImmutable $to = null): self
    {
        $this->dateRanges[$name] = ['from' => $from, 'to' => $to, 'label' => $label];

        return $this;
    }

    public function addSearchBox(?array $fields = [], ?array $options = []): self
    {
        $this->searchBoxFields = $fields;

        return $this;
    }

    public function build(): FilterOrderHelper
    {
        $helper = new FilterOrderHelper(
            $this->formFactory,
            $this->requestStack
        );

        $helper->setSearchBox($this->searchBoxFields);

        foreach (
            $this->checkboxes as $name => [
                'choices' => $choices,
                'default' => $default,
                'trans' => $trans,
            ]
        ) {
            $helper->addCheckbox($name, $choices, $default, $trans);
        }

        foreach (
            $this->dateRanges as $name => [
                'from' => $from,
                'to' => $to,
                'label' => $label,
            ]
        ) {
            $helper->addDateRange($name, $label, $from, $to);
        }

        return $helper;
    }
}
