<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\PersonBundle\Export\Aggregator\SocialWorkAggregators;

use Chill\MainBundle\Export\AggregatorInterface;
use Chill\MainBundle\Repository\UserJobRepository;
use Chill\MainBundle\Templating\TranslatableStringHelper;
use Chill\PersonBundle\Export\Declarations;
use Doctrine\ORM\QueryBuilder;
use Symfony\Component\Form\FormBuilderInterface;
use function in_array;

final readonly class JobAggregator implements AggregatorInterface
{
    public function __construct(private UserJobRepository $jobRepository, private TranslatableStringHelper $translatableStringHelper)
    {
    }

    public function addRole(): ?string
    {
        return null;
    }

    public function alterQuery(QueryBuilder $qb, $data)
    {
        if (!in_array('acpwuser', $qb->getAllAliases(), true)) {
            $qb->leftJoin('acpw.referrers', 'acpwuser');
        }

        $qb->addSelect('IDENTITY(acpwuser.userJob) as job_aggregator')
            ->addGroupBy('job_aggregator');
    }

    public function applyOn(): string
    {
        return Declarations::SOCIAL_WORK_ACTION_TYPE;
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        // no form
    }

    public function getLabels($key, array $values, $data)
    {
        return function ($value): string {
            if ('_header' === $value) {
                return 'Job';
            }

            if (null === $value || '' === $value) {
                return '';
            }

            $j = $this->jobRepository->find($value);

            return $this->translatableStringHelper->localize(
                $j->getLabel()
            );
        };
    }

    public function getQueryKeys($data): array
    {
        return ['job_aggregator'];
    }

    public function getTitle(): string
    {
        return 'Group by treating agent job';
    }
}
