<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\PersonBundle\Export\Filter\AccompanyingCourseFilters;

use Chill\MainBundle\Entity\UserJob;
use Chill\MainBundle\Export\FilterInterface;
use Chill\MainBundle\Repository\UserJobRepositoryInterface;
use Chill\MainBundle\Templating\TranslatableStringHelper;
use Chill\PersonBundle\Export\Declarations;
use Doctrine\ORM\QueryBuilder;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\FormBuilderInterface;
use function in_array;

class CreatorJobFilter implements FilterInterface
{
    public function __construct(private readonly TranslatableStringHelper $translatableStringHelper, private readonly UserJobRepositoryInterface $userJobRepository)
    {
    }

    public function addRole(): ?string
    {
        return null;
    }

    public function alterQuery(QueryBuilder $qb, $data)
    {
        if (!in_array('acp_creator', $qb->getAllAliases(), true)) {
            $qb->join('acp.createdBy', 'acp_creator');
        }

        $qb
            ->andWhere($qb->expr()->in('acp_creator.userJob', ':creator_job'))
            ->setParameter('creator_job', $data['creator_job']);
    }

    public function applyOn(): string
    {
        return Declarations::ACP_TYPE;
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        $builder->add('creator_job', EntityType::class, [
            'class' => UserJob::class,
            'choices' => $this->userJobRepository->findAllActive(),
            'choice_label' => fn (UserJob $j) => $this->translatableStringHelper->localize(
                $j->getLabel()
            ),
            'multiple' => true,
            'expanded' => true,
            'label' => 'Job',
        ]);
    }

    public function describeAction($data, $format = 'string'): array
    {
        $creatorJobs = [];

        foreach ($data['creator_job'] as $j) {
            $creatorJobs[] = $this->translatableStringHelper->localize(
                $j->getLabel()
            );
        }

        return ['export.filter.course.creator_job.Filtered by creator job: only %jobs%', [
            '%jobs%' => implode(', ', $creatorJobs),
        ]];
    }

    public function getTitle(): string
    {
        return 'Filter by creator job';
    }
}
