<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\PersonBundle\Export\Filter\AccompanyingCourseFilters;

use Chill\MainBundle\Export\FilterInterface;
use Chill\MainBundle\Templating\TranslatableStringHelper;
use Chill\PersonBundle\Entity\SocialWork\SocialAction;
use Chill\PersonBundle\Export\Declarations;
use Chill\PersonBundle\Form\Type\PickSocialActionType;
use Chill\PersonBundle\Templating\Entity\SocialActionRender;
use Doctrine\ORM\QueryBuilder;
use Symfony\Component\Form\FormBuilderInterface;
use function in_array;

class SocialActionFilter implements FilterInterface
{
    public function __construct(private readonly TranslatableStringHelper $translatableStringHelper, private readonly SocialActionRender $actionRender)
    {
    }

    public function addRole(): ?string
    {
        return null;
    }

    public function alterQuery(QueryBuilder $qb, $data)
    {
        if (!in_array('acpw', $qb->getAllAliases(), true)) {
            $qb->join('acp.works', 'acpw');
        }

        if (!in_array('acpwsocialaction', $qb->getAllAliases(), true)) {
            $qb->join('acpw.socialAction', 'acpwsocialaction');
        }

        $clause = $qb->expr()->in('acpwsocialaction.id', ':socialactions');

        $qb->andWhere($clause)
            ->setParameter(
                'socialactions',
                SocialAction::getDescendantsWithThisForActions($data['accepted_socialactions'])->toArray()
            );
    }

    public function applyOn(): string
    {
        return Declarations::ACP_TYPE;
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        $builder->add('accepted_socialactions', PickSocialActionType::class, [
            'multiple' => true,
        ]);
    }

    public function describeAction($data, $format = 'string'): array
    {
        $actions = [];

        $socialactions = $data['accepted_socialactions'];

        foreach ($socialactions as $action) {
            $actions[] = $this->actionRender->renderString($action, [
                'show_and_children' => true,
            ]);
        }

        return ['Filtered by socialactions: only %socialactions%', [
            '%socialactions%' => implode(', ', $actions),
        ]];
    }

    public function getTitle(): string
    {
        return 'Filter by socialaction';
    }
}
