<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\PersonBundle\Export\Filter\SocialWorkFilters;

use Chill\MainBundle\Entity\UserJob;
use Chill\MainBundle\Export\FilterInterface;
use Chill\MainBundle\Templating\TranslatableStringHelper;
use Chill\PersonBundle\Export\Declarations;
use Doctrine\ORM\Query\Expr\Andx;
use Doctrine\ORM\QueryBuilder;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Contracts\Translation\TranslatorInterface;
use function in_array;

class JobFilter implements FilterInterface
{
    public function __construct(protected TranslatorInterface $translator, private readonly TranslatableStringHelper $translatableStringHelper)
    {
    }

    public function addRole(): ?string
    {
        return null;
    }

    public function alterQuery(QueryBuilder $qb, $data)
    {
        if (!in_array('acpwuser', $qb->getAllAliases(), true)) {
            $qb->join('acpw.referrers', 'acpwuser');
        }

        $where = $qb->getDQLPart('where');
        $clause = $qb->expr()->in('acpwuser.userJob', ':job');

        if ($where instanceof Andx) {
            $where->add($clause);
        } else {
            $where = $qb->expr()->andX($clause);
        }

        $qb->add('where', $where);
        $qb->setParameter('job', $data['job']);
    }

    public function applyOn()
    {
        return Declarations::SOCIAL_WORK_ACTION_TYPE;
    }

    public function buildForm(FormBuilderInterface $builder)
    {
        $builder->add('job', EntityType::class, [
            'class' => UserJob::class,
            'choice_label' => fn (UserJob $j) => $this->translatableStringHelper->localize(
                $j->getLabel()
            ),
            'multiple' => true,
            'expanded' => true,
        ]);
    }

    public function describeAction($data, $format = 'string')
    {
        $userjobs = [];

        foreach ($data['job'] as $j) {
            $userjobs[] = $this->translatableStringHelper->localize(
                $j->getLabel()
            );
        }

        return ['Filtered by treating agent job: only %jobs%', [
            '%jobs%' => implode(', ', $userjobs),
        ]];
    }

    public function getTitle(): string
    {
        return 'Filter by treating agent job';
    }
}
