<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\PersonBundle\Tests\Export\Export;

use Chill\MainBundle\Test\Export\AbstractExportTest;
use Chill\PersonBundle\Export\Export\ListPerson;
use DateTime;
use Prophecy\PhpUnit\ProphecyTrait;

/**
 * Test the export "ListPerson".
 *
 * @internal
 * @coversNothing
 */
final class ListPersonTest extends AbstractExportTest
{
    use ProphecyTrait;

    private ListPerson $export;

    protected function setUp(): void
    {
        self::bootKernel();

        $this->export = self::$container->get('chill.person.export.list_person');

        $request = $this->prophesize()
            ->willExtend(\Symfony\Component\HttpFoundation\Request::class);

        $request->getLocale()->willReturn('fr');

        self::$container->get('request_stack')
            ->push($request->reveal());
    }

    public function getExport()
    {
        return $this->export;
    }

    public function getFormData(): array
    {
        return [
            ['fields' => ['id', 'firstName', 'lastName']],
            ['fields' => ['id', 'birthdate', 'gender', 'memo', 'email', 'phonenumber']],
            ['fields' => ['firstName', 'lastName', 'phonenumber']],
            ['fields' => ['id', 'nationality']],
            ['fields' => ['id', 'countryOfBirth']],
            ['fields' => ['id', 'address_street_address_1',
                'address_street_address_2', 'address_valid_from',
                'address_postcode_label', 'address_postcode_code',
                'address_country_name', 'address_country_code', ],
                'address_date' => DateTime::createFromFormat('Y-m-d', '2016-06-12'), ],
        ];
    }

    public function getModifiersCombination(): array
    {
        return [
            ['person'],
        ];
    }
}
