<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\PersonBundle\Tests\Export\Filter\AccompanyingCourseFilters;

use Chill\MainBundle\Entity\User;
use Chill\MainBundle\Test\Export\AbstractFilterTest;
use Chill\PersonBundle\Export\Filter\AccompanyingCourseFilters\ReferrerFilter;
use Doctrine\ORM\EntityManagerInterface;

/**
 * @internal
 * @coversNothing
 */
final class ReferrerFilterTest extends AbstractFilterTest
{
    private ReferrerFilter $filter;

    protected function setUp(): void
    {
        self::bootKernel();

        $this->filter = self::$container->get('chill.person.export.filter_referrer');
    }

    public function getFilter()
    {
        return $this->filter;
    }

    public function getFormData(): array
    {
        $em = self::$container->get(EntityManagerInterface::class);

        $array = $em->createQueryBuilder()
            ->from(User::class, 'u')
            ->select('u')
            ->getQuery()
            ->getResult();

        $data = [];

        foreach ($array as $u) {
            $data[] = ['accepted_referrers' => $u];
        }

        return $data;
    }

    public function getQueryBuilders(): array
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        $em = self::$container->get(EntityManagerInterface::class);

        return [
            $em->createQueryBuilder()
                ->from('ChillPersonBundle:AccompanyingPeriod', 'acp')
                ->select('acp.id'),
            $em->createQueryBuilder()
                ->from('ChillPersonBundle:AccompanyingPeriod\AccompanyingPeriodWork', 'acpw')
                ->select('acpw.id'),
            $em->createQueryBuilder()
                ->from('ChillPersonBundle:AccompanyingPeriod\AccompanyingPeriodWork', 'acpw')
                ->join('acpw.referrers', 'acpwuser')
                ->select('acpwuser.id'),
        ];
    }
}
