<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\PersonBundle\Tests\Export\Filter\PersonFilters;

use Chill\MainBundle\Test\Export\AbstractFilterTest;
use Chill\PersonBundle\Export\Filter\PersonFilters\BirthdateFilter;
use DateTime;

/**
 * @internal
 * @coversNothing
 */
final class BirthdateFilterTest extends AbstractFilterTest
{
    private BirthdateFilter $filter;

    protected function setUp(): void
    {
        self::bootKernel();

        $this->filter = self::$container->get('chill.person.export.filter_birthdate');
    }

    public function getFilter()
    {
        return $this->filter;
    }

    public function getFormData()
    {
        return [
            [
                'date_from' => DateTime::createFromFormat('Y-m-d', '2000-01-01'),
                'date_to' => DateTime::createFromFormat('Y-m-d', '2010-01-01'),
            ],
        ];
    }

    public function getQueryBuilders()
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        $em = self::$container
            ->get('doctrine.orm.entity_manager');

        return [
            $em->createQueryBuilder()
                ->select('p.firstName')
                ->from('ChillPersonBundle:Person', 'p'),
            $em->createQueryBuilder()
                ->select('p.firstName')
                ->from('ChillPersonBundle:Person', 'p')
                // add a dummy where clause
                ->where('p.firstname IS NOT NULL'),
            $em->createQueryBuilder()
                ->select('count(IDENTITY(p))')
                ->from('ChillPersonBundle:Person', 'p')
                // add a dummy where clause
                ->where('p.firstname IS NOT NULL'),
        ];
    }
}
