<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\PersonBundle\Tests\Export\Filter\PersonFilters;

use Chill\MainBundle\Test\Export\AbstractFilterTest;
use Chill\PersonBundle\Entity\Person;
use Chill\PersonBundle\Entity\Person\ResidentialAddress;
use Chill\PersonBundle\Export\Filter\PersonFilters\ResidentialAddressAtThirdpartyFilter;
use Chill\ThirdPartyBundle\Entity\ThirdPartyCategory;
use DateTime;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\Query\Expr;

/**
 * @internal
 * @coversNothing
 */
final class ResidentialAddressAtThirdpartyFilterTest extends AbstractFilterTest
{
    private ResidentialAddressAtThirdpartyFilter $filter;

    protected function setUp(): void
    {
        self::bootKernel();

        $this->filter = self::$container->get('chill.person.export.filter_residential_address_at_thirdparty');
    }

    public function getFilter()
    {
        return $this->filter;
    }

    public function getFormData(): array
    {
        $em = self::$container->get(EntityManagerInterface::class);

        $array = $em->createQueryBuilder()
            ->from(ThirdPartyCategory::class, 'tpc')
            ->select('tpc')
            ->getQuery()
            ->getResult();

        $data = [];

        foreach ($array as $r) {
            $data[] = [
                'thirdparty_cat' => $r,
                'date_calc' => DateTime::createFromFormat('Y-m-d', '2022-05-01'),
            ];
        }

        return $data;
    }

    public function getQueryBuilders(): array
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        $em = self::$container->get(EntityManagerInterface::class);

        return [
            $em->createQueryBuilder()
                ->select('p.id')
                ->from(Person::class, 'p')
                ->join(ResidentialAddress::class, 'resaddr', Expr\Join::WITH, 'resaddr.person = p')
                ->join('p.center', 'center')
                ->join('resaddr.hostThirdParty', 'tparty')
                ->join('tparty.categories', 'tpartycat'),
        ];
    }
}
