<?php

declare(strict_types=1);

/*
 * Chill is a software for social workers
 *
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

namespace Chill\ReportBundle\Tests\Export\Filter;

use Chill\MainBundle\Test\Export\AbstractFilterTest;
use Chill\ReportBundle\Entity\Report;
use Chill\ReportBundle\Export\Filter\ReportDateFilter;
use DateTime;
use Doctrine\ORM\EntityManagerInterface;

/**
 * @internal
 * @coversNothing
 */
final class ReportDateFilterTest extends AbstractFilterTest
{
    private ReportDateFilter $filter;

    protected function setUp(): void
    {
        self::bootKernel();

        $this->filter = self::$container->get('chill.report.export.filter_date');
    }

    public function getFilter()
    {
        return $this->filter;
    }

    public function getFormData(): array
    {
        return [
            [
                'date_from' => DateTime::createFromFormat('Y-m-d', '2021-07-01'),
                'date_to' => DateTime::createFromFormat('Y-m-d', '2022-07-01'),
            ],
        ];
    }

    public function getQueryBuilders(): array
    {
        if (null === self::$kernel) {
            self::bootKernel();
        }

        $em = self::$container->get(EntityManagerInterface::class);

        return [
            $em->createQueryBuilder()
                ->select('r.id')
                ->from(Report::class, 'r'),
        ];
    }
}
